package goods

import (
	"spaceofcheng/services/controllers"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service/goods"
)

// GoodsController 商品
type GoodsController struct {
	dao *goods.GoodsServ
	controllers.BaseController
}

// Constructor 初始化 Controller
// @Title Constructor
// @Description 初始化 Controller, 系统自动调用
func (c *GoodsController) Constructor() {
	c.dao = goods.NewGoodsServ(c.Context)
}

// GetGoodsType 获取商品分类列表
func (c *GoodsController) GetGoodsType() {
	caseids := c.GetString("caseid")
	if caseids == "" {
		cases := c.Context.Get("cases").([]model.SysUserCase)
		caseids = c.GetCaseIDs(cases)
	}
	page, _ := c.GetInt("page")
	pageSize, _ := c.GetInt("pagesize")
	goodstype, err := c.dao.GetGoodsType(caseids, page, pageSize)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(goodstype)
}

// GetGoodsTypeByID 根据ID获取商品分类
func (c *GoodsController) GetGoodsTypeByID() {
	typeid := c.GetString(":typeid")
	goodsType, err := c.dao.GetGoodsTypeByID(typeid)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(goodsType)
}

// SaveGoodsType 保存商品分类
func (c *GoodsController) SaveGoodsType() {
	goodsType := model.TdGoodsType{}
	if err := c.ParseForm(&goodsType); err != nil {
		c.ResponseError(err)
	}
	newtype, err := c.dao.SaveGoodsType(goodsType)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(newtype)
}

// DelGoodsType 删除商品分类
func (c *GoodsController) DelGoodsType() {
	typeid := c.GetString(":typeid")
	err := c.dao.DelGoodsType(typeid)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON("删除成功！")
}

// GetGoodsSpec 获取商品规格列表
func (c *GoodsController) GetGoodsSpec() {
	caseids := c.GetString("caseid")
	if caseids == "" {
		cases := c.Context.Get("cases").([]model.SysUserCase)
		caseids = c.GetCaseIDs(cases)
	}
	page, _ := c.GetInt("page")
	pageSize, _ := c.GetInt("pagesize")
	goodsSpec, err := c.dao.GetGoodsSpec(caseids, page, pageSize)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(goodsSpec)
}

// GetGoodsSpecByID 根据ID获取商品分类
func (c *GoodsController) GetGoodsSpecByID() {
	specid := c.GetString(":specid")
	goodsSpec, err := c.dao.GetGoodsSpecByID(specid)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(goodsSpec)
}

// SaveGoodsSpec 保存商品分类
func (c *GoodsController) SaveGoodsSpec() {
	goodsSpec := model.TdSpec{}
	if err := c.ParseForm(&goodsSpec); err != nil {
		c.ResponseError(err)
	}
	newSpec, err := c.dao.SaveGoodsSpec(goodsSpec)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(newSpec)
}

// DelGoodsSpec 删除商品分类
func (c *GoodsController) DelGoodsSpec() {
	specid := c.GetString(":specid")
	err := c.dao.DelGoodsSpec(specid)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON("删除成功！")
}
