package user

import (
	"spaceofcheng/services/controllers"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/service"
)

// UserController 用户
type UserController struct {
	dao *service.UserServ
	controllers.BaseController
}

// Constructor 初始化 Controller
// @Title Constructor
// @Description 初始化 Controller, 系统自动调用
func (c *UserController) Constructor() {
	c.dao = service.NewUserServ(c.Context)
}

// UpdatePassword 更新用户密码
func (c *UserController) UpdatePassword() {
	oriPasswd := c.GetString("oriPasswd")
	newPasswd := c.GetString("newPasswd")

	user := c.Context.Get("user").(model.SysUser)
	err := c.dao.UpdatePassword(oriPasswd, newPasswd, &user)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON("ok")
}

// ResetPassword 重置用户密码
func (c *UserController) ResetPassword() {
	userid := c.GetString("userid")
	err := c.dao.ResetPassword(userid)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON("OK")
}

// GetUserByID 获取用户信息
func (c *UserController) GetUserByID() {
	userid := c.GetString("userid")
	user, err := c.dao.GetUserByID(userid)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(user)
}

// GetUserList 获取用户列表
func (c *UserController) GetUserList() {
	userName := c.GetString("username")
	typeID := c.GetString("typeid")
	cases := c.Context.Get("cases").([]model.SysUserCase)
	caseIDs := c.GetCaseIDs(cases)
	userList, err := c.dao.GetUserList(userName, typeID, caseIDs)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(userList)
}

// UserMapping 用户映射
func (c *UserController) UserMapping() {
	userid := ""
	usertype := ""
	openid := c.GetString("openid")
	uuid := c.GetString("uuid")
	accountType := c.GetString("type")
	accountInfo := c.GetString("userinfo")
	var userMapping = model.TaUserMapping{}
	userMapping.UserId = userid
	userMapping.UserType = usertype
	userMapping.AccountInfo = accountInfo
	userMapping.Openid = openid
	userMapping.Uuid = uuid
	userMapping.AccountType = accountType

}
