package goods

import (
	"spaceofcheng/services/models"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/utils"
	"strings"
)

// GetGoodsSpecCount 获取商品规格总数
func (m *GoodsDAO) GetGoodsSpecCount(caseids string) (int64, error) {
	total, err := m.db.Where("status>?", models.STATUS_DEL).Count()
	return total, err
}

// GetGoodsSpec 根据案场获取商品规格
func (m *GoodsDAO) GetGoodsSpec(caseids string, page int, pageSize int) ([]model.TdSpec, error) {
	var goodsSpec []model.TdSpec
	err := m.db.Where("status>?", models.STATUS_DEL).And("case_id in ('"+strings.Replace(caseids, ",", "','", -1)+"')").Limit(pageSize, page*pageSize).Find(&goodsSpec)
	return goodsSpec, err
}

// GetGoodsSpecByID 根据ID获取商品规格
func (m *GoodsDAO) GetGoodsSpecByID(specid string) (*model.TdSpec, error) {
	var goodsSpec = model.TdSpec{}
	_, err := m.db.Where("status>?", models.STATUS_DEL).And("spec_id=?", specid).Get(&goodsSpec)
	return &goodsSpec, err
}

// AddGoodsSpec 新增商品规格
func (m *GoodsDAO) AddGoodsSpec(goodsSpec *model.TdSpec) (*model.TdSpec, error) {
	goodsSpec.SpecId = utils.GetGUID()
	_, err := m.db.Insert(goodsSpec)
	return goodsSpec, err
}

// UpdateGoodsSpec 修改商品规格
func (m *GoodsDAO) UpdateGoodsSpec(goodsSpec model.TdSpec) error {
	var cols = []string{
		"spec_name",
	}
	_, err := m.db.Update(goodsSpec, cols, "spec_id=?", goodsSpec.SpecId)
	return err
}

// DelGoodsSpec 刪除商品规格
func (m *GoodsDAO) DelGoodsSpec(specid string) error {
	var goodsSpec = model.TdSpec{
		SpecId: specid,
		Status: models.STATUS_DEL,
	}
	var cols = []string{
		"status",
	}
	_, err := m.db.Update(goodsSpec, cols, "spec_id=?", goodsSpec.SpecId)
	return err
}
