package system

import (
	"spaceofcheng/services/models"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/utils"
	"strings"
	"time"
	"wechat/helper"

	"github.com/go-xorm/builder"
	"github.com/go-xorm/xorm"
	"github.com/yl10/kit/encrypt"
)

// UserDAO 当前数据库操作对象
type UserDAO struct {
	ctx *utils.Context
	db  *xorm.Session
}

// NewUserDAO New Inst
func NewUserDAO(ctx *utils.Context) *UserDAO {
	return &UserDAO{
		ctx: ctx,
		db:  ctx.DB,
	}
}

// GetUserList 用户列表
func (m *UserDAO) GetUserList(username, typeid, caseids string) ([]model.SysUser, error) {
	var users []model.SysUser
	userDAO := m.db.Where(`(status>? and user_name like '%?%' and user_id in 
		(select user_id from sys_user_tag a inner join sys_tag_case b on a.tag_id=b.tag_id where b.case_id in ('?')))`, models.STATUS_DEL, username, strings.Replace(caseids, ",", "','", -1))

	if typeid != "" {
		userDAO.In("user_id", builder.Select("user_id").From("sys_user_type").Where(builder.Eq{"type_id": typeid}))
	}
	err := userDAO.Find(&users)
	return users, err
}

// UserInfo 用户详情
type UserInfo struct {
	model.SysUser `xorm:"extends"`
	UserType      []model.TdUserType
	UserTag       []model.SysTag
	UserCase      []model.SysCase
	UserRole      []model.SysRole
	UserMenu      []model.SysMenu
}

// GetUserByID 根据ID获取用户信息
func (m *UserDAO) GetUserByID(userid string) (*UserInfo, error) {
	var userinfo = UserInfo{}
	_, err := m.db.Table("sys_user").Where("user_id=?", userid).And("status>?", models.STATUS_DEL).Get(&userinfo)
	if err != nil {
		return nil, err
	}
	return &userinfo, nil
}

// GetUserType 获取用户类型
func (m *UserDAO) GetUserType(userid string) ([]model.TdUserType, error) {
	var usertype []model.TdUserType
	err := m.db.In("type_id", builder.Select("type_id").From("sys_user_type").Where(builder.Eq{"user_id": userid}).And(builder.Gt{"status": models.STATUS_DEL})).Find(&usertype)
	return usertype, err
}

// GetUserTag 获取用户标签
func (m *UserDAO) GetUserTag(userid string) ([]model.SysTag, error) {
	var userTag []model.SysTag
	err := m.db.In("tag_id", builder.Select("tag_id").From("sys_user_tag").Where(builder.Eq{"user_id": userid}).And(builder.Gt{"status": models.STATUS_DEL})).Find(&userTag)
	return userTag, err
}

// GetUserCase 获取用户案场
func (m *UserDAO) GetUserCase(userid string) ([]model.SysCase, error) {
	var userCase []model.SysCase
	err := m.db.In("case_id", builder.Select("case_id").From("sys_user_case").Where(builder.Eq{"user_id": userid}).And(builder.Gt{"status": models.STATUS_DEL})).Find(&userCase)
	return userCase, err
}

// GetUserRole 获取用户角色
func (m *UserDAO) GetUserRole(userid string) ([]model.SysRole, error) {
	var userRole []model.SysRole
	err := m.db.In("role_id", builder.Select("role_id").From("sys_user_role").Where(builder.Eq{"user_id": userid}).And(builder.Gt{"status": models.STATUS_DEL})).Find(&userRole)
	return userRole, err
}

// GetUserMenu 获取用户菜单
func (m *UserDAO) GetUserMenu(userid string) ([]model.SysMenu, error) {
	var userMenu []model.SysMenu
	err := m.db.In("menu_id", builder.Select("menu_id").From("sys_user_menu").Where(builder.Eq{"user_id": userid}).And(builder.Gt{"status": models.STATUS_DEL})).Find(&userMenu)
	return userMenu, err
}

// AddUser 新增用户
func (m *UserDAO) AddUser(user model.SysUser) (*model.SysUser, error) {
	user.UserId = utils.GetGUID()
	user.CreateDate = time.Now()
	user.Status = models.STATUS_NOMAIL
	_, err := m.db.Insert(&user)
	return &user, err
}

// UpdateUser 修改用户
func (m *UserDAO) UpdateUser(user model.SysUser) error {
	var col = []string{
		"user_name",
		"real_name",
		"sex",
		"work_no",
		"email",
		"phone",
		"headimgurl",
		"user_type_name",
	}
	_, err := m.db.Update(user, col, "user_id=?", user.UserId)
	return err
}

// DelUser 删除用户
func (m *UserDAO) DelUser(userid string) error {
	var user = model.SysUser{}
	user.Status = models.STATUS_DEL
	user.UserId = userid
	var col = []string{
		"status",
	}
	_, err := m.db.Update(user, col, "user_id=?", user.UserId)
	return err
}

// DelUserType 删除用户对应的类型信息
func (m *UserDAO) DelUserType(userid string) error {
	sql := "delete from sys_user_type where user_id='" + userid + "'"
	_, err := m.db.Exec(sql)
	return err
}

// SaveUserType 保存用户对应类型信息
func (m *UserDAO) SaveUserType(userid, typeids string) error {
	sql := `insert into sys_user_type(user_id,type_id) select '` + userid + `', type_id from td_user_type where type_id in ('` + strings.Replace(typeids, ",", "','", -1) + `') and status>?`
	_, err := m.db.Exec(sql, models.STATUS_DEL)
	return err
}

// DelUserRole 删除用户对应的角色信息
func (m *UserDAO) DelUserRole(userid string) error {
	sql := "delete from sys_user_role where user_id='" + userid + "'"
	_, err := m.db.Exec(sql)
	return err
}

// SaveUserRole 保存用户对应角色信息
func (m *UserDAO) SaveUserRole(userid, roleids string) error {
	sql := `insert into sys_user_role(user_id,role_id) select '` + userid + `', role_id from sys_role where role_id in ('` + strings.Replace(roleids, ",", "','", -1) + `') and status>?`
	_, err := m.db.Exec(sql, models.STATUS_DEL)
	return err
}

// DelUserTag 删除用户对应的标签信息
func (m *UserDAO) DelUserTag(userid string) error {
	sql := "delete from sys_user_tag where user_id='" + userid + "'"
	_, err := m.db.Exec(sql)
	return err
}

// SaveUserTag 保存用户对应标签信息
func (m *UserDAO) SaveUserTag(userid, tagids string) error {
	sql := `insert into sys_user_tag(user_id,tag_id) select '` + userid + `', tag_id from sys_tag where tag_id in ('` + strings.Replace(tagids, ",", "','", -1) + `') and status>?`
	_, err := m.db.Exec(sql, models.STATUS_DEL)
	return err
}

// DelUserCase 删除用户对应的案场
func (m *UserDAO) DelUserCase(userid string) error {
	sql := "delete from sys_user_case where user_id='" + userid + "'"
	_, err := m.db.Exec(sql)
	return err
}

// SaveUserCase 保存用户对应案场信息
func (m *UserDAO) SaveUserCase(usercase model.SysUserCase) error {
	usercase.CreateDate = time.Now()
	usercase.Status = models.STATUS_NOMAIL
	_, err := m.db.Insert(&usercase)
	return err
}

// SaveUserCaseByUserTag 根据用户标签保存用户对应案场
func (m *UserDAO) SaveUserCaseByUserTag(userid string) error {
	sql := `insert into sys_user_case(user_id, case_id, case_name, is_belong, status, create_date) 
	select c.user_id, a.case_id,a.case_name, 0,?,now() from sys_case a 
	inner join sys_tag_case b on a.case_id = b.case_id
	inner join sys_user_tag c on b.tag_id = c.tag_id
	where c.user_id = ? and a.status > ?`

	_, err := m.db.Exec(sql, models.STATUS_NOMAIL, userid, models.STATUS_DEL)
	return err
}

// ValidatePassword 验证密码是否正确
func (m *UserDAO) ValidatePassword(user *model.SysUser, password string) bool {
	return user.Pwd == encrypt.Md5(password, user.UserId)
}

// UpdatePassword 更新用户密码
func (m *UserDAO) UpdatePassword(userID, newPass string) error {
	password := encrypt.Md5(newPass, userID)

	sql := "update sys_user set passwd=? where user_id=?"

	_, err := m.db.Exec(sql, password, userID)
	if err != nil {
		return helper.LogError("更新新密码出错", err)
	}

	return nil
}

// SaveUserMapping 保存用户映射信息
func (m *UserDAO) SaveUserMapping(usermapping *model.TaUserMapping) error {
	usermapping.MappingId = utils.GetGUID()
	_, err := m.db.Insert(&usermapping)
	return err
}
