package service

import (
	"errors"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/models/system"
	"spaceofcheng/services/utils"

	"github.com/yl10/kit/encrypt"
)

const (
	USERTYPE_USER     = "user"
	USERTYPE_CUSTOMER = "customer"
)

// UserServ 系统处理
type UserServ struct {
	ctx *utils.Context
	dao *system.UserDAO
}

// NewUserServ 初始化
func NewUserServ(ctx *utils.Context) *UserServ {
	return &UserServ{
		ctx: ctx,
		dao: system.NewUserDAO(ctx),
	}
}

// GetUserList 获取用户列表
func (s *UserServ) GetUserList(username, typeid, caseids string) ([]model.SysUser, error) {
	userList, err := s.dao.GetUserList(username, typeid, caseids)
	return userList, err
}

// GetUserByID 根据用户ID获取用户信息
func (s *UserServ) GetUserByID(userid string) (*system.UserInfo, error) {
	userinfo, err := s.dao.GetUserByID(userid)
	if err != nil {
		return nil, err
	}
	usertype, err := s.dao.GetUserType(userid)
	if err != nil {
		return nil, err
	}
	userinfo.UserType = usertype

	usertag, err := s.dao.GetUserTag(userid)
	if err != nil {
		return nil, err
	}
	userinfo.UserTag = usertag

	usercase, err := s.dao.GetUserCase(userid)
	if err != nil {
		return nil, err
	}
	userinfo.UserCase = usercase

	userrole, err := s.dao.GetUserRole(userid)
	if err != nil {
		return nil, err
	}
	userinfo.UserRole = userrole

	usermenu, err := s.dao.GetUserMenu(userid)
	if err != nil {
		return nil, err
	}
	userinfo.UserMenu = usermenu

	return userinfo, nil
}

// SaveUser 用户保存
func (s *UserServ) SaveUser() (*model.SysUser, error) {
	return nil, nil
}

// UpdatePassword 密码修改
func (s *UserServ) UpdatePassword(oriPasswd, newPasswd string, user *model.SysUser) error {
	if !s.dao.ValidatePassword(user, oriPasswd) {
		return errors.New("密码错误！")
	}

	if err := s.dao.UpdatePassword(user.UserId, newPasswd); err != nil {
		return err
	}

	return nil
}

// ResetPassword 重设密码
func (s *UserServ) ResetPassword(userid string) error {
	newPasswd := encrypt.Md5("123456")
	if err := s.dao.UpdatePassword(userid, newPasswd); err != nil {
		return err
	}

	return nil
}

// UserMapping 用户隐射
func (s *UserServ) UserMapping(userMapping model.TaUserMapping) error {
	err := s.dao.SaveUserMapping(&userMapping)
	if err != nil {
		return err
	}
	// 根据用户类型更新用户表中的数据

	switch userMapping.UserType {
	case USERTYPE_USER:
		break
	case USERTYPE_CUSTOMER:
		break
	}
	return nil
}
